@@ -38,6 +38,7 @@ __all__ = (
     "AccessConfigurationTypeDef",
     "AdBreakTypeDef",
     "AdMarkerPassthroughTypeDef",
+    "AlertTypeDef",
     "AvailSuppressionTypeDef",
     "BumperTypeDef",
     "CdnConfigurationTypeDef",
@@ -78,6 +79,8 @@ __all__ = (
     "HlsPlaylistSettingsTypeDef",
     "HttpConfigurationTypeDef",
     "HttpPackageConfigurationTypeDef",
+    "ListAlertsRequestRequestTypeDef",
+    "ListAlertsResponseTypeDef",
     "ListChannelsRequestRequestTypeDef",
     "ListChannelsResponseTypeDef",
     "ListPlaybackConfigurationsRequestRequestTypeDef",
@@ -147,6 +150,17 @@ AdMarkerPassthroughTypeDef = TypedDict(
     total=False,
 )
 
+AlertTypeDef = TypedDict(
+    "AlertTypeDef",
+    {
+        "AlertCode": str,
+        "AlertMessage": str,
+        "LastModifiedTime": datetime,
+        "RelatedResourceArns": List[str],
+        "ResourceArn": str,
+    },
+)
+
 AvailSuppressionTypeDef = TypedDict(
     "AvailSuppressionTypeDef",
     {
@@ -635,6 +649,37 @@ HttpPackageConfigurationTypeDef = TypedDict(
     },
 )
 
+_RequiredListAlertsRequestRequestTypeDef = TypedDict(
+    "_RequiredListAlertsRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+_OptionalListAlertsRequestRequestTypeDef = TypedDict(
+    "_OptionalListAlertsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListAlertsRequestRequestTypeDef(
+    _RequiredListAlertsRequestRequestTypeDef, _OptionalListAlertsRequestRequestTypeDef
+):
+    pass
+
+
+ListAlertsResponseTypeDef = TypedDict(
+    "ListAlertsResponseTypeDef",
+    {
+        "Items": List["AlertTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListChannelsRequestRequestTypeDef = TypedDict(
     "ListChannelsRequestRequestTypeDef",
     {
